@@ -12,6 +12,7 @@ from .api import (
     MessageIn,
     MessageOut,
     Svix,
+    SvixAsync,
     SvixOptions,
 )
 from .webhooks import Webhook, WebhookVerificationError
@@ -30,9 +31,10 @@ __all__ = [
     "MessageIn",
     "MessageOut",
     "Svix",
+    "SvixAsync",
     "SvixOptions",
     "Webhook",
     "WebhookVerificationError",
 ]
 
-__version__ = "0.47.0"
+__version__ = "0.54.1"
